"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.init = exports.initFlags = void 0;
const path_1 = __importDefault(require("path"));
const splat_1 = require("./splat");
const files_1 = require("../util/files");
const resolveLatestVersions_1 = require("../npm/resolveLatestVersions");
const sharedFlags_1 = __importDefault(require("../sharedFlags"));
const package_1 = require("../npm/package");
const default_source_1 = require("../configs/default-source");
const constants_1 = require("../constants");
exports.initFlags = Object.assign(Object.assign({}, sharedFlags_1.default), { scripts: {
        type: 'boolean',
        default: true,
    }, eslint: {
        type: 'boolean',
        default: true,
    }, typescript: {
        type: 'boolean',
        default: true,
    }, prettier: {
        type: 'boolean',
        default: true,
    }, license: {
        type: 'string',
    }, editorconfig: {
        type: 'boolean',
        default: true,
    }, gitignore: {
        type: 'boolean',
        default: true,
    }, force: {
        type: 'boolean',
        default: false,
    }, install: {
        type: 'boolean',
        default: true,
    }, name: {
        type: 'string',
    }, author: {
        type: 'string',
    }, repo: {
        type: 'string',
    } });
const defaultDependencies = [constants_1.incompatiblePluginPackage];
// purple-unicorn as version in devDependencies will install 2.29.5, so must be explicit
// using ^2.29.5-purple-unicorn.856 is not safe either
const defaultDevDependencies = { react: '^17.0.0 || ^18.0.0', sanity: '2.29.5-purple-unicorn.856' };
const defaultPeerDependencies = { react: '^17.0.0 || ^18.0.0', sanity: 'purple-unicorn' };
function init(options) {
    return __awaiter(this, void 0, void 0, function* () {
        let dependencies = {};
        let devDependencies = {};
        let peerDependencies = {};
        dependencies = Object.assign(Object.assign({}, dependencies), (yield (0, resolveLatestVersions_1.resolveLatestVersions)(defaultDependencies)));
        devDependencies = Object.assign(Object.assign(Object.assign({}, devDependencies), defaultDevDependencies), (yield (0, resolveLatestVersions_1.resolveLatestVersions)(['rimraf'])));
        peerDependencies = Object.assign(Object.assign({}, peerDependencies), defaultPeerDependencies);
        yield (0, splat_1.splat)(Object.assign(Object.assign({}, options), { requireUserConfirmation: !options.flags.force, dependencies,
            devDependencies,
            peerDependencies, validate: false }));
        const packageJson = yield (0, package_1.getPackage)({ basePath: options.basePath, validate: false });
        const typescript = options.flags.typescript;
        const source = typescript ? (0, default_source_1.defaultSourceTs)(packageJson) : (0, default_source_1.defaultSourceJs)(packageJson);
        const filename = typescript ? 'index.ts' : 'index.js';
        const srcDir = path_1.default.resolve(options.basePath, 'src');
        yield (0, files_1.ensureDir)(srcDir);
        yield (0, files_1.writeFile)(path_1.default.join(srcDir, filename), source, { encoding: 'utf8' });
    });
}
exports.init = init;
//# sourceMappingURL=init.js.map