"use strict";
/*
ISC License (ISC)
Copyright 2019 Johan Otterud

Permission to use, copy, modify, and/or distribute this software for any purpose with or without fee is hereby granted,
provided that the above copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH
THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.linkWatch = void 0;
/*
This code is a modified version of https://github.com/johot/yalc-watch,
and the ISC License has been added for this file only, in accordance with the package.json license field in that package
*/
const nodemon_1 = __importDefault(require("nodemon"));
const concurrently_1 = __importDefault(require("concurrently"));
const chalk_1 = __importDefault(require("chalk"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const log_1 = __importDefault(require("../util/log"));
const package_1 = require("../npm/package");
const outdent_1 = __importDefault(require("outdent"));
function linkWatch({ basePath }) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        const packageJson = JSON.parse(fs_1.default.readFileSync(path_1.default.join(process.cwd(), 'package.json'), 'utf8'));
        const watch = Object.assign({ folder: 'lib', command: 'npm run watch', extensions: 'js,png,svg,gif,jpeg,css' }, (_a = packageJson.sanityPlugin) === null || _a === void 0 ? void 0 : _a.linkWatch);
        (0, nodemon_1.default)({
            watch: [watch.folder],
            ext: watch.extensions,
            exec: 'yalc push --changed',
            //delay: 1000
        });
        const pkg = yield (0, package_1.getPackage)({ basePath, validate: false });
        nodemon_1.default
            .on('start', function () {
            log_1.default.info((0, outdent_1.default) `
        Watching ${watch.folder} for changes to files with extensions: ${watch.extensions}

        To test this package in another repository directory run:
        ${chalk_1.default.greenBright(`npx yalc add ${pkg.name} && npx yalc link ${pkg.name} && npm install`)}
      `.trimStart());
        })
            .on('quit', function () {
            process.exit();
        })
            .on('restart', function (files) {
            log_1.default.info('Found changes in files:', chalk_1.default.magentaBright(files));
            log_1.default.info('Pushing new yalc package...');
        });
        (0, concurrently_1.default)([watch.command]);
    });
}
exports.linkWatch = linkWatch;
//# sourceMappingURL=link-watch.js.map