"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.verifyPackage = void 0;
const package_1 = require("../npm/package");
const log_1 = __importDefault(require("../util/log"));
const constants_1 = require("../constants");
const import_linter_1 = require("../dependencies/import-linter");
const outdent_1 = __importDefault(require("outdent"));
const verify_common_1 = require("./verify/verify-common");
const files_1 = require("../util/files");
const validations_1 = require("./verify/validations");
const chalk_1 = __importDefault(require("chalk"));
function verifyPackage({ basePath, flags }) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        let errors = [];
        const packageJson = yield (0, package_1.getPackage)({ basePath, validate: false });
        const verifyConfig = ((_a = packageJson.sanityPlugin) === null || _a === void 0 ? void 0 : _a.verifyPackage) || {};
        const validation = (0, verify_common_1.createValidator)(verifyConfig, flags, errors);
        const tsConfig = yield (0, files_1.readJson5File)({ basePath, filename: 'tsconfig.json' });
        yield validation('packageName', () => __awaiter(this, void 0, void 0, function* () { return (0, validations_1.validatePackageName)(packageJson); }));
        yield validation('parcel', () => __awaiter(this, void 0, void 0, function* () { return (0, validations_1.validateParcelDependency)(packageJson); }));
        yield validation('scripts', () => __awaiter(this, void 0, void 0, function* () { return (0, validations_1.validateScripts)(packageJson); }));
        yield validation('module', () => __awaiter(this, void 0, void 0, function* () { return (0, validations_1.validateModule)(packageJson); }));
        yield validation('nodeEngine', () => __awaiter(this, void 0, void 0, function* () { return (0, validations_1.validateNodeEngine)(packageJson); }));
        tsConfig && (yield validation('tsconfig', () => __awaiter(this, void 0, void 0, function* () { return (0, validations_1.validateTsConfig)(tsConfig); })));
        yield validation('sanityV2Json', () => __awaiter(this, void 0, void 0, function* () { return (0, validations_1.validatePluginSanityJson)({ basePath, packageJson }); }));
        yield validation('rollupConfig', () => __awaiter(this, void 0, void 0, function* () { return (0, validations_1.validateRollupConfig)({ basePath }); }));
        yield validation('babelConfig', () => __awaiter(this, void 0, void 0, function* () { return (0, validations_1.validateBabelConfig)({ basePath }); }));
        yield validation('dependencies', () => __awaiter(this, void 0, void 0, function* () { return (0, validations_1.validateSanityDependencies)(packageJson); }));
        yield validation('eslintImports', () => __awaiter(this, void 0, void 0, function* () { return (0, import_linter_1.validateImports)({ basePath }); }));
        if (errors.length) {
            throw new Error((0, outdent_1.default) `
        Detected validation issues!
        To make this package Sanity v3 compatible, fix the issues starting from the top, or disable any checks you deem unnecessary.

        These issues assume the package uses @sanity/plugin-kit defaults for development and building.
        Refer to ${constants_1.urls.pluginReadme} for configuration options.

        More information is available here:
        - Studio migration guide: ${constants_1.urls.migrationGuideStudio}
        - Plugin migration guide: ${constants_1.urls.migrationGuidePlugin}
        - Reference documentation: ${constants_1.urls.refDocs}

        ${chalk_1.default.grey(`To fail-fast on first detected issue run:\nnpx ${constants_1.cliName} verify-package' --single`)}
      `.trimStart());
        }
        yield (0, verify_common_1.runTscMaybe)(verifyConfig, tsConfig);
        log_1.default.success((0, outdent_1.default) `
    No outstanding upgrade issues detected.

    Suggested next steps:
      - Use plugin-kit to build and develop the plugin according to ${constants_1.urls.pluginReadme}.
      - Build the plugin and fix any compilation errors
      - Test the plugin using the link-watch command
  `.trim());
    });
}
exports.verifyPackage = verifyPackage;
//# sourceMappingURL=verify-package.js.map