"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.verifyStudio = void 0;
const package_1 = require("../npm/package");
const log_1 = __importDefault(require("../util/log"));
const files_1 = require("../util/files");
const constants_1 = require("../constants");
const import_linter_1 = require("../dependencies/import-linter");
const outdent_1 = __importDefault(require("outdent"));
const chalk_1 = __importDefault(require("chalk"));
const verify_common_1 = require("./verify/verify-common");
const validations_1 = require("./verify/validations");
function verifyStudio({ basePath, flags }) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        let errors = [];
        const packageJson = yield (0, package_1.getPackage)({ basePath, validate: false });
        const verifyConfig = ((_a = packageJson.sanityPlugin) === null || _a === void 0 ? void 0 : _a.verifyPackage) || {};
        const validation = (0, verify_common_1.createValidator)(verifyConfig, flags, errors);
        const tsConfig = yield (0, files_1.readJson5File)({ basePath, filename: 'tsconfig.json' });
        yield validation('studioConfig', () => __awaiter(this, void 0, void 0, function* () { return (0, validations_1.validateStudioConfig)({ basePath }); }));
        yield validation('dependencies', () => __awaiter(this, void 0, void 0, function* () { return (0, validations_1.validateSanityDependencies)(packageJson); }));
        yield validation('eslintImports', () => __awaiter(this, void 0, void 0, function* () { return (0, import_linter_1.validateImports)({ basePath }); }));
        if (errors.length) {
            throw new Error((0, outdent_1.default) `
        Detected validation issues!
        This Sanity Studio is not completely V3 ready. Fix the issues starting from the top, or disable any checks you deem unnecessary.

        More information is available here:
        - Migration guide: ${constants_1.urls.migrationGuideStudio}
        - Reference documentation: ${constants_1.urls.refDocs}

        ${chalk_1.default.grey(`To fail-fast on first detected issue run:\nnpx ${constants_1.cliName} verify-studio --single`)}
      `.trimStart());
        }
        yield (0, verify_common_1.runTscMaybe)(verifyConfig, tsConfig);
        log_1.default.success((0, outdent_1.default) `
    No outstanding upgrade issues detected. Studio is V3 ready!
  `.trim());
    });
}
exports.verifyStudio = verifyStudio;
//# sourceMappingURL=verify-studio.js.map