"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const meow_1 = __importDefault(require("meow"));
const package_json_1 = __importDefault(require("../../package.json"));
const sharedFlags_1 = __importDefault(require("../sharedFlags"));
const link_watch_1 = require("../actions/link-watch");
const description = `Run the watch command and pushes any changes to yalc`;
const help = `
Usage
  $ ${package_json_1.default.binname} link-watch [<args>]

Options
  --silent      Do not print info and warning messages
  --verbose     Log everything. This option conflicts with --silent
  --version     Output the version number
  --help        Output usage information

Configuration
To override the default watch command configuration, provide an override in package.json under sanityPlugin:
{
  "sanityPlugin": {
    "watchCommand": "microbundle watch --format modern,esm,cjs --jsx React.createElement --jsxImportSource react --css inline",
    "linkWatch": {
      "folder": "lib",
      "command": "npm run watch",
      "extensions": "js,png,svg,gif,jpeg,css"
    }
  }
}

Examples
  # Run the watch command and pushes any changes to yalc
  $ ${package_json_1.default.binname} link-watch
`;
const flags = Object.assign(Object.assign({}, sharedFlags_1.default), { watch: {
        type: 'boolean',
        default: false,
    } });
function run({ argv }) {
    const cli = (0, meow_1.default)(help, { flags, argv, description });
    const basePath = path_1.default.resolve(cli.input[0] || process.cwd());
    return (0, link_watch_1.linkWatch)({ basePath });
}
exports.default = run;
//# sourceMappingURL=link-watch.js.map