"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const meow_1 = __importDefault(require("meow"));
const package_json_1 = __importDefault(require("../../package.json"));
const log_1 = __importDefault(require("../util/log"));
const splat_1 = require("../actions/splat");
const manifest_1 = require("../sanity/manifest");
const init_1 = require("../actions/init");
const description = `"Splat" configuration into a Sanity plugin`;
const help = `
Usage
  $ ${package_json_1.default.binname} splat [dir]  [<args>]

Options
  --no-eslint        Disables ESLint config and dependencies from being added
  --no-prettier      Disables prettier config and dependencies from being added
  --no-typescript    Disables typescript config and dependencies from being added
  --no-license       Disables LICENSE + package.json license field from being added
  --no-editorconfig  Disables .editorconfig from being added
  --no-gitignore     Disables .gitignore from being added
  --no-scripts       Disables scripts from being added to package.json
  --license [spdx]   Use the license with the given SPDX identifier

Examples
  # Splat configuration into the plugin in the current directory
  $ ${package_json_1.default.binname} splat

  # Splat configuration into the plugin in ~/my-plugin
  $ ${package_json_1.default.binname} splat ~/my-plugin

  # Don't add eslint or prettier
  $ ${package_json_1.default.binname} splat --no-eslint --no-prettier
`;
function run({ argv }) {
    return __awaiter(this, void 0, void 0, function* () {
        const cli = (0, meow_1.default)(help, { flags: init_1.initFlags, argv, description });
        const basePath = path_1.default.resolve(cli.input[0] || process.cwd());
        const { exists, isRoot } = yield (0, manifest_1.hasSanityJson)(basePath);
        if (exists && isRoot) {
            throw new Error(`sanity.json has a "root" property set to true - are you trying to splat into a studio instead of a plugin?`);
        }
        if (!exists) {
            throw new Error(`sanity.json does not exist in this directory, maybe you want "${package_json_1.default.binname} init" instead?`);
        }
        yield (0, splat_1.splat)({ basePath, flags: cli.flags });
        log_1.default.info('Done!');
    });
}
exports.default = run;
//# sourceMappingURL=splat.js.map