"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const meow_1 = __importDefault(require("meow"));
const package_json_1 = __importDefault(require("../../package.json"));
const log_1 = __importDefault(require("../util/log"));
const sharedFlags_1 = __importDefault(require("../sharedFlags"));
const description = `Show the installed version of ${package_json_1.default.name}`;
const help = `
Usage
  $ ${package_json_1.default.binname} version

Options
  --major  Show only the major version
  --minor  Show only the minor version
  --patch  Show only the patch version

Examples
  $ ${package_json_1.default.binname} version
  ${package_json_1.default.name} version ${package_json_1.default.version}

  $ ${package_json_1.default.binname} version --major
  ${package_json_1.default.version.split('.')[0]}
`;
const flags = Object.assign(Object.assign({}, sharedFlags_1.default), { major: {
        type: 'boolean',
        default: false,
    }, minor: {
        type: 'boolean',
        default: false,
    }, patch: {
        type: 'boolean',
        default: false,
    } });
function run({ argv }) {
    const cli = (0, meow_1.default)(help, { flags, argv, description });
    const versionParts = package_json_1.default.version.split('.');
    const versionNames = ['major', 'minor', 'patch'];
    const versionFlags = versionNames.filter((flagName) => cli.flags[flagName]);
    const versionFlag = versionFlags[0];
    const numVersionFlags = versionFlags.length;
    if (numVersionFlags === 0) {
        log_1.default.msg(`${package_json_1.default.name} version ${package_json_1.default.version}`);
        return;
    }
    if (numVersionFlags > 1) {
        throw new Error(`--major, --minor and --patch are mutually exclusive - only one can be used at a time`);
    }
    const partIndex = versionNames.indexOf(versionFlag);
    log_1.default.msg(versionParts[partIndex]);
}
exports.default = run;
//# sourceMappingURL=version.js.map