"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.installDependencies = exports.promptForPackageManager = exports.pnpmAvailable = exports.yarnIsAvailable = exports.npmIsAvailable = void 0;
const execa_1 = __importDefault(require("execa"));
const prompt_1 = require("../util/prompt");
function npmIsAvailable() {
    return (0, execa_1.default)('npm', ['-v'])
        .then(() => true)
        .catch(() => false);
}
exports.npmIsAvailable = npmIsAvailable;
function yarnIsAvailable() {
    return (0, execa_1.default)('yarn', ['-v'])
        .then(() => true)
        .catch(() => false);
}
exports.yarnIsAvailable = yarnIsAvailable;
function pnpmAvailable() {
    return (0, execa_1.default)('pnpm', ['-v'])
        .then(() => true)
        .catch(() => false);
}
exports.pnpmAvailable = pnpmAvailable;
function promptForPackageManager() {
    return __awaiter(this, void 0, void 0, function* () {
        const [npm, yarn, pnpm] = yield Promise.all([
            npmIsAvailable(),
            yarnIsAvailable(),
            pnpmAvailable(),
        ]);
        const choices = [npm && 'npm', yarn && 'yarn', pnpm && 'pnpm'].filter(Boolean);
        if (choices.length < 2) {
            return choices[0] || 'npm';
        }
        return (0, prompt_1.prompt)('Which package manager do you prefer?', {
            choices: choices.map((value) => ({ value, name: value })),
            default: choices[0],
        });
    });
}
exports.promptForPackageManager = promptForPackageManager;
function installDependencies(pm, { cwd }) {
    return __awaiter(this, void 0, void 0, function* () {
        const proc = (0, execa_1.default)(pm, ['install'], { cwd, stdio: 'inherit' });
        const { exitCode } = yield proc;
        return exitCode <= 0;
    });
}
exports.installDependencies = installDependencies;
//# sourceMappingURL=manager.js.map