"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runCommand = exports.parseCommand = void 0;
const child_process_1 = __importDefault(require("child_process"));
const npm_run_path_1 = __importDefault(require("npm-run-path"));
const log_1 = __importDefault(require("./log"));
function parseCommand(commandString) {
    const normalized = commandString.replace(/ +/g, ' ');
    const commandAndArg = normalized.split(' ');
    return {
        command: commandAndArg[0],
        args: commandAndArg.length > 1 ? commandAndArg.slice(1) : [],
    };
}
exports.parseCommand = parseCommand;
function runCommand(commandString) {
    return __awaiter(this, void 0, void 0, function* () {
        log_1.default.info(`Running command: ${commandString}`);
        const { command, args } = parseCommand(commandString);
        let options = { stdio: 'inherit', env: npm_run_path_1.default.env() };
        // ref: https://stackoverflow.com/questions/37459717/error-spawn-enoent-on-windows/37487465
        options = process.platform === 'win32' ? Object.assign(Object.assign({}, options), { shell: true }) : options;
        return new Promise((resolve, reject) => {
            child_process_1.default
                .spawn(command, args, options)
                .on('error', reject)
                .on('close', (exitCode) => {
                resolve({ code: exitCode !== null && exitCode !== void 0 ? exitCode : 0 });
            });
        });
    });
}
exports.runCommand = runCommand;
//# sourceMappingURL=command-parser.js.map