"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseJson5 = exports.readJson5File = exports.readFileContent = exports.isEmptyish = exports.ensureDir = exports.getFileHash = exports.filesAreEqual = exports.fileEqualsData = exports.copyFileWithOverwritePrompt = exports.writeFileWithOverwritePrompt = exports.writeJsonFile = exports.readJsonFile = exports.fileExists = exports.buildCandidateExists = exports.hasCompiledFile = exports.hasSourceFile = exports.hasSourceEquivalent = exports.writeFile = exports.readFile = exports.copyFile = exports.readdir = exports.mkdir = exports.stat = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const util_1 = __importDefault(require("util"));
const p_any_1 = __importDefault(require("p-any"));
const crypto_1 = __importDefault(require("crypto"));
const buildExtensions_1 = require("../configs/buildExtensions");
const prompt_1 = require("./prompt");
const log_1 = __importDefault(require("./log"));
const json5_1 = __importDefault(require("json5"));
exports.stat = util_1.default.promisify(fs_1.default.stat);
exports.mkdir = util_1.default.promisify(fs_1.default.mkdir);
exports.readdir = util_1.default.promisify(fs_1.default.readdir);
exports.copyFile = util_1.default.promisify(fs_1.default.copyFile);
exports.readFile = util_1.default.promisify(fs_1.default.readFile);
exports.writeFile = util_1.default.promisify(fs_1.default.writeFile);
function hasSourceEquivalent(compiledFile, paths) {
    if (!paths.source) {
        return fileExists(path_1.default.isAbsolute(compiledFile) ? compiledFile : path_1.default.resolve(paths.basePath, compiledFile));
    }
    // /plugin/lib/MyComponent.js => /plugin/src
    const baseDir = path_1.default.dirname(compiledFile.replace(paths.compiled, paths.source));
    // /plugin/lib/MyComponent.js => MyComponent
    const baseName = path_1.default.basename(compiledFile, path_1.default.extname(compiledFile));
    // MyComponent => /plugin/src/MyComponent
    const pathStub = path_1.default.join(baseDir, baseName);
    /*
     * /plugin/src/MyComponent => [
     *   /plugin/src/MyComponent.jsx,
     *   /plugin/src/MyComponent.mjs,
     *   ...
     * ]
     */
    return buildCandidateExists(pathStub);
}
exports.hasSourceEquivalent = hasSourceEquivalent;
// Generally used for parts resolving
function hasSourceFile(filePath, paths) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        if (!(paths === null || paths === void 0 ? void 0 : paths.source)) {
            return fileExists(path_1.default.isAbsolute(filePath) ? filePath : path_1.default.resolve((_a = paths === null || paths === void 0 ? void 0 : paths.basePath) !== null && _a !== void 0 ? _a : '', filePath));
        }
        // filePath: components/SomeInput
        // paths: {source: '/plugin/src'}
        // MyComponent => /plugin/src/MyComponent
        const pathStub = path_1.default.isAbsolute(filePath) ? filePath : path_1.default.resolve(paths.source, filePath);
        if (yield fileExists(pathStub)) {
            return true;
        }
        return buildCandidateExists(pathStub);
    });
}
exports.hasSourceFile = hasSourceFile;
// Generally used for parts resolving
function hasCompiledFile(filePath, paths) {
    var _a;
    if (!(paths === null || paths === void 0 ? void 0 : paths.compiled)) {
        return fileExists(path_1.default.isAbsolute(filePath) ? filePath : path_1.default.resolve((_a = paths === null || paths === void 0 ? void 0 : paths.basePath) !== null && _a !== void 0 ? _a : '', filePath));
    }
    // filePath: components/SomeInput
    // paths: {compiled: '/plugin/lib'}
    // components/SomeInput => /plugin/lib/components/SomeInput
    const absPath = path_1.default.isAbsolute(filePath) ? filePath : path_1.default.resolve(paths.compiled, filePath);
    // /plugin/lib/components/SomeInput     => /plugin/lib/components/SomeInput.js
    // /plugin/lib/components/SomeInput.js  => /plugin/lib/components/SomeInput.js
    // /plugin/lib/components/SomeInput.css => /plugin/lib/components/SomeInput.css
    const fileExt = path_1.default.extname(absPath);
    const withExt = fileExt === '' ? `${absPath}.js` : absPath;
    return fileExists(withExt);
}
exports.hasCompiledFile = hasCompiledFile;
function buildCandidateExists(pathStub) {
    const candidates = buildExtensions_1.buildExtensions.map((extCandidate) => `${pathStub}${extCandidate}`);
    return (0, p_any_1.default)(candidates.map((candidate) => (0, exports.stat)(candidate)))
        .then(() => true)
        .catch(() => false);
}
exports.buildCandidateExists = buildCandidateExists;
function fileExists(filePath) {
    return (0, exports.stat)(filePath)
        .then(() => true)
        .catch(() => false);
}
exports.fileExists = fileExists;
function readJsonFile(filePath) {
    return __awaiter(this, void 0, void 0, function* () {
        const content = yield (0, exports.readFile)(filePath, 'utf8');
        return JSON.parse(content);
    });
}
exports.readJsonFile = readJsonFile;
function writeJsonFile(filePath, content) {
    const data = JSON.stringify(content, null, 2);
    return (0, exports.writeFile)(filePath, data, { encoding: 'utf8' });
}
exports.writeJsonFile = writeJsonFile;
function writeFileWithOverwritePrompt(filePath, content, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const { default: defaultVal, force = false } = options, writeOptions = __rest(options, ["default", "force"]);
        const withinCwd = filePath.startsWith(process.cwd());
        const printablePath = withinCwd ? path_1.default.relative(process.cwd(), filePath) : filePath;
        if (yield fileEqualsData(filePath, content)) {
            return false;
        }
        if (!force &&
            (yield fileExists(filePath)) &&
            !(yield (0, prompt_1.prompt)(`File "${printablePath}" already exists. Overwrite?`, {
                type: 'confirm',
                default: defaultVal,
            }))) {
            return false;
        }
        yield (0, exports.writeFile)(filePath, content, writeOptions);
        return true;
    });
}
exports.writeFileWithOverwritePrompt = writeFileWithOverwritePrompt;
function copyFileWithOverwritePrompt(from, to, flags) {
    return __awaiter(this, void 0, void 0, function* () {
        const withinCwd = to.startsWith(process.cwd());
        const printablePath = withinCwd ? path_1.default.relative(process.cwd(), to) : to;
        if (yield filesAreEqual(from, to)) {
            return false;
        }
        if (!flags.force &&
            (yield fileExists(to)) &&
            !(yield (0, prompt_1.prompt)(`File "${printablePath}" already exists. Overwrite?`, {
                type: 'confirm',
                default: false,
            }))) {
            return false;
        }
        yield (0, exports.copyFile)(from, to);
        return true;
    });
}
exports.copyFileWithOverwritePrompt = copyFileWithOverwritePrompt;
function fileEqualsData(filePath, content) {
    return __awaiter(this, void 0, void 0, function* () {
        const contentHash = crypto_1.default.createHash('sha1').update(content).digest('hex');
        const remoteHash = yield getFileHash(filePath);
        return contentHash === remoteHash;
    });
}
exports.fileEqualsData = fileEqualsData;
function filesAreEqual(file1, file2) {
    return __awaiter(this, void 0, void 0, function* () {
        const [hash1, hash2] = yield Promise.all([getFileHash(file1, false), getFileHash(file2)]);
        return hash1 === hash2;
    });
}
exports.filesAreEqual = filesAreEqual;
function getFileHash(filePath, allowMissing = true) {
    return new Promise((resolve, reject) => {
        const hash = crypto_1.default.createHash('sha1');
        const stream = fs_1.default.createReadStream(filePath);
        stream.on('error', (err) => {
            if (err.code === 'ENOENT' && allowMissing) {
                resolve(null);
            }
            else {
                reject(err);
            }
        });
        stream.on('end', () => resolve(hash.digest('hex')));
        stream.on('data', (chunk) => hash.update(chunk));
    });
}
exports.getFileHash = getFileHash;
function ensureDir(dirPath) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            yield (0, exports.mkdir)(dirPath);
        }
        catch (err) {
            if (err.code !== 'EEXIST') {
                throw err;
            }
        }
    });
}
exports.ensureDir = ensureDir;
function isEmptyish(dirPath) {
    return __awaiter(this, void 0, void 0, function* () {
        const ignoredFiles = ['.git', '.gitignore', 'license', 'readme.md'];
        const allFiles = yield (0, exports.readdir)(dirPath).catch(() => []);
        const files = allFiles.filter((file) => !ignoredFiles.includes(file.toLowerCase()));
        return files.length === 0;
    });
}
exports.isEmptyish = isEmptyish;
function readFileContent({ filename, basePath, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const filepath = path_1.default.normalize(path_1.default.join(basePath, filename));
        try {
            return yield (0, exports.readFile)(filepath, 'utf8');
        }
        catch (err) {
            if (err.code === 'ENOENT') {
                log_1.default.debug(`No ${filename} file found.`);
                return undefined;
            }
            throw new Error(`Failed to read "${filepath}": ${err.message}`);
        }
    });
}
exports.readFileContent = readFileContent;
function readJson5File({ filename, basePath, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const content = yield readFileContent({ filename, basePath });
        if (!content) {
            return undefined;
        }
        return parseJson5(content, filename);
    });
}
exports.readJson5File = readJson5File;
function parseJson5(content, errorKey) {
    try {
        return json5_1.default.parse(content);
    }
    catch (err) {
        throw new Error(`Error parsing "${errorKey}": ${err.message}`);
    }
}
exports.parseJson5 = parseJson5;
//# sourceMappingURL=files.js.map