"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isDefaultGitHubReadme = exports.getLicenseText = exports.generateReadme = void 0;
const outdent_1 = __importDefault(require("outdent"));
// @ts-expect-error missing types
const choosealicense_list_1 = __importDefault(require("@rexxars/choosealicense-list"));
function generateReadme(data) {
    const { user, pluginName, license, description } = data;
    return (0, outdent_1.default) `
    # ${pluginName}

    ## Installation

    \`\`\`
    npm install --save ${pluginName}
    \`\`\`

    or

    \`\`\`
    yarn add ${pluginName}
    \`\`\`

    ## Usage
    Add it as a plugin in sanity.config.ts (or .js):

    \`\`\`
     import {createConfig} from 'sanity'
     import {myPlugin} from '${pluginName}'

     export const createConfig({
         /...
         plugins: [
             myPlugin({})
         ]
     })
    \`\`\`
    ${getLicenseText(license === null || license === void 0 ? void 0 : license.id, (user === null || user === void 0 ? void 0 : user.name) ? user : undefined)}
  `;
}
exports.generateReadme = generateReadme;
function getLicenseText(licenseId, user) {
    if (!licenseId) {
        return '';
    }
    let licenseName = choosealicense_list_1.default.find(licenseId).title;
    licenseName = licenseName === null || licenseName === void 0 ? void 0 : licenseName.replace(/\s+license$/i, '');
    let licenseText = '## License\n';
    if (licenseName && (user === null || user === void 0 ? void 0 : user.name)) {
        licenseText = `${licenseText}\n${licenseName} © ${user === null || user === void 0 ? void 0 : user.name}\nSee LICENSE`;
    }
    else if (licenseName) {
        licenseText = `${licenseText}\n${licenseName}\nSee LICENSE`;
    }
    else {
        licenseText = `${licenseText}\nSee LICENSE`;
    }
    return licenseText;
}
exports.getLicenseText = getLicenseText;
function isDefaultGitHubReadme(readme) {
    if (!readme) {
        return false;
    }
    const lines = readme.split('\n', 20).filter(Boolean);
    // title + _optional_ description
    return lines.length <= 2 && lines[0].startsWith('#');
}
exports.isDefaultGitHubReadme = isDefaultGitHubReadme;
//# sourceMappingURL=readme.js.map