"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPackageUserInfo = exports.getUserInfo = void 0;
const path_1 = __importDefault(require("path"));
const xdg_basedir_1 = __importDefault(require("xdg-basedir"));
// @ts-expect-error missing types
const git_user_info_1 = __importDefault(require("git-user-info"));
const email_validator_1 = require("email-validator");
const files_1 = require("./files");
const request_1 = require("./request");
const prompt_1 = require("./prompt");
function getUserInfo({ requireUserConfirmation, flags }, pkg) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        const userInfo = getPackageUserInfo({ author: (_a = flags.author) !== null && _a !== void 0 ? _a : pkg === null || pkg === void 0 ? void 0 : pkg.author }) ||
            (yield getSanityUserInfo()) ||
            (yield getGitUserInfo());
        if (requireUserConfirmation) {
            return promptForInfo(userInfo);
        }
        return userInfo;
    });
}
exports.getUserInfo = getUserInfo;
function getPackageUserInfo(pkg) {
    if (!pkg || !pkg.author) {
        return undefined;
    }
    if (!pkg.author.includes('@')) {
        return { name: pkg.author };
    }
    const [pre, ...post] = pkg.author.replace(/[<>[\]]/g, '').split(/@/);
    const nameParts = pre.split(/\s+/);
    const email = [nameParts[nameParts.length - 1], ...post].join('@');
    const name = nameParts.slice(0, -1).join(' ');
    return { name, email };
}
exports.getPackageUserInfo = getPackageUserInfo;
function promptForInfo(defValue) {
    return __awaiter(this, void 0, void 0, function* () {
        const name = yield (0, prompt_1.prompt)('Author name', {
            filter: filterString,
            default: defValue && defValue.name,
            validate: requiredString,
        });
        const email = yield (0, prompt_1.prompt)('Author email', {
            filter: filterString,
            default: defValue && defValue.email,
            validate: validOrEmptyEmail,
        });
        return { name, email };
    });
}
function getSanityUserInfo() {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const data = yield (0, files_1.readJsonFile)(path_1.default.join((_a = xdg_basedir_1.default.config) !== null && _a !== void 0 ? _a : '', 'sanity', 'config.json'));
            const token = data === null || data === void 0 ? void 0 : data.authToken;
            if (!token) {
                return undefined;
            }
            const user = yield (0, request_1.request)({
                url: 'https://api.sanity.io/v1/users/me',
                headers: { Authorization: `Bearer ${token}` },
            });
            if (!user) {
                return undefined;
            }
            const { name, email } = user;
            return { name, email };
        }
        catch (err) {
            return undefined;
        }
    });
}
function getGitUserInfo() {
    const user = (0, git_user_info_1.default)();
    return user ? { name: user.name, email: user.email } : undefined;
}
function filterString(val) {
    return (val || '').trim();
}
function requiredString(value) {
    return value.length > 1 ? true : 'Required';
}
function validOrEmptyEmail(value) {
    if (!value) {
        return true;
    }
    return (0, email_validator_1.validate)(value) ? true : 'Must either be a valid email or empty';
}
//# sourceMappingURL=user.js.map