"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const tap_1 = __importDefault(require("tap"));
const fixture_utils_1 = require("./fixture-utils");
const constants_1 = require("../src/constants");
const normalize = (dirPath) => dirPath.replace(/\//g, path_1.default.sep);
const helpString = 'These are common commands used in various situations';
tap_1.default.test('shows help if no command is given', (t) => __awaiter(void 0, void 0, void 0, function* () {
    const { stdout, stderr, exitCode } = yield (0, fixture_utils_1.runCliCommand)('', []);
    t.equal(exitCode, 2, 'should have exit code 2');
    t.equal(stderr, '');
    t.match(stdout, helpString);
    t.match(stdout, constants_1.cliName);
}));
tap_1.default.test('shows error + help on unknown commands', (t) => __awaiter(void 0, void 0, void 0, function* () {
    const { stdout, stderr, exitCode } = yield (0, fixture_utils_1.runCliCommand)('does-not-exist', []);
    t.equal(exitCode, 2, 'should have exit code 2');
    t.equal(stderr, 'Unknown command "does-not-exist"');
    t.match(stdout, helpString);
    t.match(stdout, constants_1.cliName);
}));
tap_1.default.test('shows error + help when using both --silent and --verbose', (t) => __awaiter(void 0, void 0, void 0, function* () {
    const { stdout, stderr, exitCode } = yield (0, fixture_utils_1.runCliCommand)('version', ['--silent', '--verbose'], {
        reject: false,
    });
    t.equal(exitCode, 2, 'should have exit code 2');
    t.match(stderr, '--silent and --verbose are mutually exclusive');
    t.match(stdout, helpString);
    t.match(stdout, constants_1.cliName);
}));
tap_1.default.test('shows no stack trace without --debug', (t) => __awaiter(void 0, void 0, void 0, function* () {
    const { stdout, stderr, exitCode } = yield (0, fixture_utils_1.runCliCommand)('version', ['--major', '--minor'], {
        reject: false,
    });
    t.equal(exitCode, 1, 'should have exit code 1');
    t.equal(stdout, '', 'should have empty stdout');
    t.match(stderr, 'only one can be used at a time');
    t.notMatch(stderr, normalize('/cmds/version.js:'));
}));
tap_1.default.test('shows stack trace with --debug', (t) => __awaiter(void 0, void 0, void 0, function* () {
    const { stdout, stderr, exitCode } = yield (0, fixture_utils_1.runCliCommand)('version', [
        '--debug',
        '--major',
        '--minor',
    ]);
    t.equal(exitCode, 1, 'should have exit code 1');
    t.equal(stdout, '', 'should have empty stdout');
    t.match(stderr, 'only one can be used at a time');
    t.match(stderr, path_1.default.normalize('/cmds/version.ts'));
}));
//# sourceMappingURL=cli.test.js.map