"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runCliCommand = exports.fileContainsValidator = exports.testFixture = exports.initTestArgs = exports.pluginTestName = exports.normalize = exports.contents = exports.onlyPaths = exports.readFile = exports.readFileRaw = void 0;
const execa_1 = __importDefault(require("execa"));
const path_1 = __importDefault(require("path"));
const util_1 = __importDefault(require("util"));
const fs_1 = __importDefault(require("fs"));
const readdirp_1 = __importDefault(require("readdirp"));
const rimraf = util_1.default.promisify(require('rimraf'));
const baseFixturesDir = path_1.default.join(__dirname, 'fixtures');
exports.readFileRaw = util_1.default.promisify(fs_1.default.readFile);
const readFile = (file) => (0, exports.readFileRaw)(file, 'utf8');
exports.readFile = readFile;
const onlyPaths = (files) => files.map((file) => file.path);
exports.onlyPaths = onlyPaths;
const contents = (dir) => readdirp_1.default.promise(dir).then(exports.onlyPaths);
exports.contents = contents;
const normalize = (dirPath) => dirPath.replace(/\//g, path_1.default.sep);
exports.normalize = normalize;
exports.pluginTestName = 'sanity-plugin-test-plugin';
exports.initTestArgs = [
    '--force',
    '--no-install',
    '--name',
    exports.pluginTestName,
    '--license',
    'mit',
    '--author',
    'Test Person <test.person@somewhere-on-the-internet.nowhere>',
    '--repo',
    'https://github.com/sanity-io/sanity',
];
function testFixture({ fixturePath, relativeOutPath = 'lib', command, assert, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const fixtureDir = path_1.default.join(baseFixturesDir, (0, exports.normalize)(fixturePath));
        const outputDir = path_1.default.join(fixtureDir, (0, exports.normalize)(relativeOutPath));
        yield rimraf(outputDir);
        const result = yield command({ fixtureDir, outputDir });
        yield assert({ result, outputDir });
        yield rimraf(outputDir);
    });
}
exports.testFixture = testFixture;
function fileContainsValidator(t /* tap types cannot be imported? :shrug: */, outputDir) {
    return (file, ...contains) => __awaiter(this, void 0, void 0, function* () {
        const fileString = yield (0, exports.readFile)(path_1.default.join(outputDir, (0, exports.normalize)(file)));
        contains.forEach((content) => t.match(fileString, content, `${file} contains ${content}`));
    });
}
exports.fileContainsValidator = fileContainsValidator;
function runCliCommand(command, args = [], options) {
    return (0, execa_1.default)('ts-node', ['run-test-command.ts', command, ...args], Object.assign({ cwd: __dirname, reject: false }, options));
}
exports.runCliCommand = runCliCommand;
//# sourceMappingURL=fixture-utils.js.map